<?php
/*
Plugin Name: Alert Me!
Plugin URI: https://bloomwp.com/plugins/alertme/
Description: Easily add a signup box in a post or page that when updated will automatically send your subscribers an email alert.
Version: 1.2
Author: Bloom WP
Author URI: https://www.bloomwp.com/
*/
global $alertme_table, $alertme_plugin_dir, $alertme_plugin_url, $options, $alert_me_form_heading_text, $alert_me_form_success_message;
/**
* Define global variables values
*/
$alertme_table = 'alert_me';
$alertme_plugin_dir = untrailingslashit( plugin_dir_path( __FILE__ ) );
$alertme_plugin_url = untrailingslashit( plugin_dir_url( __FILE__ ) );
$alert_me_form_heading_text = esc_html('Send me an email when this page has been updated');
$alert_me_form_success_message = '<h2>Success! </h2><p>You will now receive an email alert anytime this page has been updated.</p>';
$alert_me_email_subject_line = 'A post has been updated';
$options = get_option( 'alertme_options', array() );
/**
 * Load Current User stuff
 */
if(!function_exists('wp_get_current_user')) {
    include(ABSPATH . "wp-includes/pluggable.php"); 
}
/**
 * Get all custom post types
*/
function alertme_getCustomPostTypes() {
	$custom_post_types = array_values( get_post_types( array( 'public' => true, '_builtin' => false ), 'objects' ) );
	return $custom_post_types;
}
/**
 * Get all custom post types
*/
function alertme_getPostTypes() {
	$getPostTypes = array_values( get_post_types( array( 'public' => true, '_builtin' => true ), 'objects' ) );
	return $getPostTypes;
}
/**
 * Admin Options
 */
if ( is_admin() ) {
	include_once $alertme_plugin_dir . '/alertme.admin.php';
	include_once $alertme_plugin_dir . '/alertme.subscribers.php';
	add_action( 'plugins_loaded', function () {
		AlertMe_load_Subscriber_page::get_instance();
	} );	
}
include_once $alertme_plugin_dir . '/alertme.notficiation.php';
/**
 * Add setting page hook
*/
function alertme_add_menu_link() {
	add_submenu_page( 'tools.php', 'Alert Me Settings', 'AlertMe',
    'manage_options', 'alert-me', 'alert_me_settings');   
}
add_filter( 'admin_menu', 'alertme_add_menu_link' );
// Place in Option List on Settings > Plugins page 
function alert_me_action_links( $links, $file ) {
	// Static so we don't call plugin_basename on every plugin row.
	static $this_plugin;
	
	if ( ! $this_plugin ) {
		$this_plugin = plugin_basename( __FILE__ );
	}
	
	if ( $file == $this_plugin ) {
		$settings_link = '<a href="tools.php?page=alert-me">' . __( 'Settings' ) . '</a>';
		array_unshift( $links, $settings_link ); // before other links
	}
	
	return $links;
}
add_filter( 'plugin_action_links', 'alert_me_action_links', 10, 2 );
/**
 * Load CSS for frontend
*/
function alert_me_load_plugin_css() {
	global $alertme_plugin_url;
	if ( ! is_admin() ) {
		wp_enqueue_style( 'alert-me-font', 'https://fonts.googleapis.com/css?family=Open+Sans:300,400,600,700,800&display=swap', false, time() );
		wp_enqueue_style( 'alert-me', plugins_url('/css/alert_me.css', __FILE__ ), false, time() );
		wp_enqueue_script( 'alert-me-js', plugins_url( '/js/alertme.js', __FILE__ ), false, time());
	}
}
add_action( 'wp_enqueue_scripts', 'alert_me_load_plugin_css', 20 );
/**
 * Add ajax URl in head for Ajax call
*/
function alert_me_ajaxurl() {
   echo '<script type="text/javascript">
           var ajaxurl = "' . admin_url('admin-ajax.php') . '";
         </script>';
}
add_action('wp_head', 'alert_me_ajaxurl');
/**
 * Activation hook
*/
function alertme_activation() {
	// Get all existing Aletme options
	$options = get_option( 'alertme_options', array() );
	// Create a table in DB to hold the singup info.
	global $wpdb, $alertme_table;
	$table_name = $wpdb->prefix . $alertme_table;
	$charset_collate = $wpdb->get_charset_collate();
    if($wpdb->get_var( "show tables like '$table_name'" ) != $table_name) { 
		$sql = "CREATE TABLE $table_name (
		  `id` bigint(20) NOT NULL auto_increment,
		  `post_id` bigint(44) COLLATE utf8mb4_unicode_ci NOT NULL,
		  `email` varchar(44) COLLATE utf8mb4_unicode_ci NOT NULL,
		  `is_unsubscribed` int(1) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT 0,
		  `created_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
		  PRIMARY KEY  (id)
		) ENGINE=MyISAM DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;";
		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
		dbDelta( $sql );
    }	
}
register_activation_hook( __FILE__, 'alertme_activation' );
/**
 * Deactivation hook
 */
function alertme_unistall() {
	global $wpdb, $alertme_table;
	update_option( 'alertme_options', array() );
	$table_name = $wpdb->prefix . $alertme_table;
	$sql = "DROP TABLE IF EXISTS $table_name;";
	$wpdb->query($sql);
	delete_option("my_plugin_db_version");	
}
register_deactivation_hook( __FILE__, 'alertme_unistall' );
register_uninstall_hook( __FILE__, 'alertme_unistall' );
function alert_me_add_to_content( $content ) {
	global $wp_current_filter;

	$options = get_option( 'alertme_options', array() );
	$post_type = get_post_type( get_the_ID() );
	$alertme_enable_post_alertme = get_post_meta( get_the_ID(), 'alertme_enable_post_alertme', true );

	// Don't add to get_the_excerpt because it's too early and strips tags (adding to the_excerpt is allowed)
	if ( in_array( 'get_the_excerpt', (array) $wp_current_filter ) || is_home() || is_search() || is_archive() || !array_key_exists($post_type , $options['display_alert_me_post_type']) || get_post_status( get_the_ID() ) == 'private') {
		// Return early
		return $content;
	}

	if ($options['alert_me_post_type_visibility_setting'][$post_type] == 'manual') {
			
			if ($alertme_enable_post_alertme == 1):

				$options['alert_me_position'] = isset( $options['alert_me_position'] ) ? $options['alert_me_position'] : 'bottom';
				if ($options['alert_me_position'] == 'both' || $options['alert_me_position'] == 'top') {
					// Prepend to content
					$content = alert_me_loadAlertMeBox($options) . '<br>' . $content;
				}
				if ( $options['alert_me_position'] == 'bottom' || $options['alert_me_position'] == 'both') {
					// Append to content
					$content .= alert_me_loadAlertMeBox($options);
				}

			endif;

	} else {
		
		$options['alert_me_position'] = isset( $options['alert_me_position'] ) ? $options['alert_me_position'] : 'bottom';
		if ($options['alert_me_position'] == 'both' || $options['alert_me_position'] == 'top') {
			// Prepend to content
			$content = alert_me_loadAlertMeBox($options) . '<br>' . $content;
		}
		if ( $options['alert_me_position'] == 'bottom' || $options['alert_me_position'] == 'both') {
			// Append to content
			$content .= alert_me_loadAlertMeBox($options);
		}
	}

	return $content;	
}

function alert_me_loadAlertMeBox( $options ) {
	global $alertme_plugin_url,$alert_me_form_heading_text, $alert_me_form_success_message,$options;
	ob_start();
?>
	<div class="alertme_email">
	  <div class="alertme_conatainer">
	    <h2 class="alertme_heading">
	    	<?php echo ((isset($options['alert_me_form_heading_text'])) ? $options['alert_me_form_heading_text'] :  $alert_me_form_heading_text ); ?>
	    </h2>
	    <form name="alert_me_form" id="alert_me_form" method="post" action="">
		    <div class="alertme_row">
		    	<?php wp_nonce_field('alert-me-email-subscribe'); ?>
		    	<input type="hidden" name="alert_me_post_id" id="alert_me_post_id" value="<?php echo get_the_ID(); ?>">
		      <div class="alertme_left">
		        <img src="<?php echo $alertme_plugin_url; ?>/images/email.svg">
		        <input type="text" name="alert_me_email" class="alertme_input" id="alert_me_email" placeholder="Email">
		      </div>
		      <div class="alertme_right">
		        <button type="button" id="alert_me_submit" class="alertme_button">
		          Subscribe
		        </button>
		      </div>
		    </div>
	    </form>
	  </div>
	</div>
<?php
    $output = ob_get_contents();
	ob_end_clean();
	return $output;
}
/*
* Handle Ajax request to store email address in DB
*/
function alert_me_subscription() {
	global $wpdb, $alertme_table, $alert_me_form_success_message;
	$result = array();
	check_admin_referer( 'alert-me-email-subscribe' );
	
	if (isset($_POST['alert_me_email']) && $_POST['alert_me_email'] != '') {
	    $table_name = $wpdb->prefix . $alertme_table;
	    $count_query = "select count(*) from " .$table_name. " WHERE email= '".sanitize_email($_POST['alert_me_email'])."' AND post_id = '".sanitize_text_field($_POST['alert_me_post_id'])."' AND is_unsubscribed = 0";
	    $alreadyCount = $wpdb->get_var($count_query);

	    if ($alreadyCount > 0) {
	    	$result['error'] = 'You have already subscibed with this email address for this post/page.';
	    } else {

	    	$count_query = "select count(*) from " .$table_name. " WHERE email= '".sanitize_email($_POST['alert_me_email'])."' AND post_id = '".sanitize_text_field($_POST['alert_me_post_id'])."' AND is_unsubscribed = 1";
	    	$alreadyUnsubscribedCount = $wpdb->get_var($count_query);

	    	if ($alreadyUnsubscribedCount > 0) {

	    		$sql = "UPDATE $table_name SET is_unsubscribed = 0 WHERE email= '".sanitize_email($_POST['alert_me_email'])."' AND post_id = '".sanitize_text_field($_POST['alert_me_post_id'])."'";
				$wpdb->query( $sql );

	    	} else {

				$data = array(
					'post_id'    => sanitize_text_field($_POST['alert_me_post_id']),
					'email' => sanitize_email($_POST['alert_me_email'])
				);
				$wpdb->insert($table_name, $data );	    		
	    	}

			$success_message = ((isset($options['alert_me_form_success_message'])) ? $options['alert_me_form_success_message'] :  $alert_me_form_success_message );
			$result['success'] = '<div class="sucess_col"><div class="sub-container">'. $success_message .'</div></div>';	    	
	    }
	} else {
		$result['error'] = 'Email should not be empty';
	}
	
	echo json_encode($result);
	exit();	
}
add_action( 'wp_ajax_alert_me_subscription', 'alert_me_subscription' );
add_action( 'wp_ajax_nopriv_alert_me_subscription', 'alert_me_subscription' );
function alert_me_pre_get_posts( $query ) {
	if ( $query->is_main_query() ) {
		// Hook to change the standard buttons' priority number in content
		// Example: add_filter( 'addtoany_content_priority', 20 );
		$priority = apply_filters( 'alert_me_content_priority', 98 );
		add_filter( 'the_content', 'alert_me_add_to_content', $priority );
	}
}
add_action( 'pre_get_posts', 'alert_me_pre_get_posts' );

/*
*
* Add shortCode in plugin
* User this [alertme-form-show] to render form
*
*/

function alert_me_shortcode_form_show() {
	if ( !is_admin() ) {
		$options = get_option( 'alertme_options', array() );
		echo alert_me_loadAlertMeBox($options);	
	}

	if (is_admin()) {
		// To load checkbox with shortcode, so admin can send notification
		$title = apply_filters( 'alertme_meta_box_title', __( 'AlertMe', 'alert-me' ) );
		add_meta_box( 'alert_me_meta', $title, 'alert_me_meta_box_content', '', 'side', 'default' );
	}
}
add_shortcode( 'alertme-form-show', 'alert_me_shortcode_form_show' );
?>